import {
  readAll,
  readerFromStreamReader,
} from "https://deno.land/std@0.97.0/io/mod.ts";
import { decode, Image } from "https://deno.land/x/jpegts@1.1/mod.ts";
import { resize } from "https://deno.land/x/deno_image@v0.0.3/mod.ts";

export const compareMunicipalRibbon = async (
  ribbonUrl: string,
  imageToCompareTo: Image,
): Promise<number> => {
  const ribbon = (await fetch(ribbonUrl))?.body?.getReader();
  if (ribbon) {
    const reader = readerFromStreamReader(ribbon);
    const rawImage = await readAll(reader);
    const picture = decode(
      await resize(rawImage, {
        height: imageToCompareTo.height,
        width: imageToCompareTo.width,
        aspectRatio: false,
      }),
    );
    return compareImages(picture, imageToCompareTo);
  }

  throw new Error("Couldn't fetch remote Image!");
};

const compareImages = (
  firstImage: Image,
  secondImage: Image,
): number => {
  if (
    firstImage.width != secondImage.width ||
    firstImage.height != secondImage.height
  ) {
    throw new Error(
      "Can't compare images of different sizes. " + firstImage.width + "x" +
        firstImage.height + " vs " + secondImage.width + "x" +
        secondImage.height,
    );
  }

  let diff = 0;
  for (let i = 0; i < firstImage.data.length / 5; i++) {
    diff += Math.abs(firstImage.data[4 * i + 0] - secondImage.data[4 * i + 0]) /
      255;
    diff += Math.abs(firstImage.data[4 * i + 1] - secondImage.data[4 * i + 1]) /
      255;
    diff += Math.abs(firstImage.data[4 * i + 2] - secondImage.data[4 * i + 2]) /
      255;
  }

  return 100 - 100 * diff / (firstImage.width * firstImage.height * 3);
};
