import { Application, Router } from "https://deno.land/x/oak@v7.3.0/mod.ts";
import { parse } from "https://deno.land/std@0.97.0/flags/mod.ts";
import logger from "https://deno.land/x/oak_logger@1.0.0/mod.ts";

import {
  compareRibbon,
  getAllRibbons,
  getRibbon,
  getRibbonCategories,
  Ribbon,
} from "./ribbon.ts";

const { args } = Deno;
const DEFAULT_PORT = 8000;
const argPort = parse(args).port;
const port = argPort ? Number(argPort) : DEFAULT_PORT;

const state: Ribbon[] = await (await fetch(
  "https://opendata.schleswig-holstein.de/dataset/d2625e54-f9f6-4ae4-99b2-e4a99ea78b11/resource/0f3f4b53-c69e-45ba-acb2-4d3e58855d32/download/wappen.json",
)).json();

const app = new Application({ state });

app.use(logger.logger);
app.use(logger.responseTime);

const router = new Router();

router.get("/ribbons", getAllRibbons);
router.get("/ribbons/:municipality", getRibbon);
router.get("/ribbons/categories/:municipality", getRibbonCategories);
router.post(
  "/ribbons/compare/:municipality",
  compareRibbon,
);

app.use(router.routes());

console.log(`Listening on port ${port}...`);
await app.listen({ port });
